Crate pkarr_republisher

Crate pkarr_republisher 

Structs

MultiRepublishResult
MultiRepublisher
Republish multiple keys in a serially or multi-threaded way/
PublishInfo
Publisher
Tries to publish a single key and verifies the keys has been published to a sufficient number of nodes. Retries in case of errors with an exponential backoff.
PublisherSettings
Settings for creating a republisher
RepublishInfo
Republisher
Tries to republish a single key. Retries in case of errors with an exponential backoff.
RepublisherSettings
Settings for creating a republisher
ResilientClient
Simple pkarr client that focuses on resilience and verification compared to the regular client that might experience inreliability due to the underlying UDP connection.
RetrySettings

Enums

PublishError
RepublishError
ResilientClientBuilderError

Functions

count_key_on_dht
Verifies the number of nodes that store the public key.

Type Aliases

RepublishCondition